#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include <unistd.h> 
#include <sys/types.h>
#include <sys/wait.h>
#include <errno.h>
#include <stdlib.h>

int my_system (const char *command) {
 int pid, status;
 
 if (command == 0)
     return 1;
 pid = fork();
 if (pid == -1)
     return -1;
 if (pid == 0) {
     char *argv[4];
     argv[0] = "sh";
     argv[1] = "-c";
     argv[2] = (char *)command;
     argv[3] = 0;
     execv("/bin/sh", argv);
     exit(127);
 }
 do {
     if (waitpid(pid, &status, 0) == -1) 
     {
      if (errno != EINTR)
       return -1;
     }
     else
       return status;

     /* Riduce l'overhead della CPU mentre lo script lavora */
     sleep(1);
 } while(1);
}


unsigned long getfilelenght(FILE * fp)
{
 long lun;
 
 fseek( fp, 0, SEEK_END);
 lun = ftell(fp);
 rewind(fp);
 
 return lun;
}


void aggiorna_timer(gint freq)
{
 int i, idx;
 GtkWidget * wchk;
 static char * chk[9]  = {"manuale", "_10sec", "_15sec", 
                          "_20sec",  "_30sec", "_1min", 
			  "_2min",   "_5min",  "_10min"};
 static int time[9] = {0, 10, 15, 20, 30,
                       60, 120, 300, 600 }, inib = 0, first = 1;

 if(inib)
  return; 

 if(Freq != freq || first)
 {
  /* 2000-03-31 Roberto A. F.
   * BUGFIX: Questo risolver il problema per cui la v0.0.8
   *         non aggiornava costantemente il refresh dei valori
   */
  first = 0;

  Freq = freq;
  if(Timer != 0)
   gtk_timeout_remove(Timer);
  Timer = 0;

  /* Determino approsimativamente quale
   * aggiornamento selezionare nel menu
   */
  idx = 0;
  for(i = 1; i < 9 && !idx; i++)
   if(Freq > time[i-1] && Freq <= time[i])
    idx = i;  
  if(Freq > time[8])
   idx = 8;
  g_print("\n\nFrequenza selezionata: %d sec", time[idx]);

  /* Aggiorno il menu delle frequenze 
   * il quale per emmette un segnale 
   * che mi devo occupare di ignorare
   */
  inib = 1;
  wchk = lookup_widget(Base, chk[idx]);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (wchk), TRUE);
  inib = 0;

  if(Freq != 0)
  {
   Timer = gtk_timeout_add( (guint32)Freq*1000, (GtkFunction)on_aggiorna_pressed, NULL );
   g_print("\nTimer frequency: %d sec", FREQ);
  }
  else
   g_print("\nTimer frequency: SOSPESA");
 }
}


void show_info_msg (void)
{
 GtkWidget * messaggio;
 char * infomsg;

 /*  Questo codice funziona anche in assenza del
  * reset del puntatore Info al destroy della 
  * finestra di nformazioni per emette un errore
  * dalle GTK+ dovuto al query di un oggettto che
  * non esiste
  */
 messaggio = (Info) ? lookup_widget(Info, "infolabel") : NULL;

 /*  Se esiste gi una finestra di informazioni
  * non serve crearne una aggiuntiva ma basta
  * visualizzare quella esistente.
  */
 if(!messaggio)
 {
  infomsg = (char *)malloc(strlen(RVERSN)+strlen(AUTHOR)+strlen(EMAIL)+strlen(WEBPAGE)+16);
  if( infomsg )
  {
   sprintf(infomsg, "\n%s\n\n%s\n%s\n%s\n", RVERSN, AUTHOR, EMAIL, WEBPAGE);
   Info = create_informazioni();
   messaggio = lookup_widget(Info, "infolabel");
   gtk_label_set (GTK_LABEL(messaggio), infomsg);
  }
  else 
   Info = create_informazioni();

  MOSTRA_ON_MOUSE(Info);
 }
 else 
  gtk_widget_show (Info);

 return;
}


void show_error_msg (const char * errmsg)
{
 GtkWidget * messaggio, * msg_errore;

 /* Inutile creare messaggi di errore
  * all'infinito si rischia solo un 
  * blocco della macchina.
  */
 if(Nerr >= MAX_ERR)
  return;

 g_print("\n\n%s\n", errmsg);

 msg_errore = create_errore();
 messaggio = lookup_widget(msg_errore, "error_msg");
 gtk_label_set (GTK_LABEL(messaggio), errmsg);
 MOSTRA_ON_MOUSE(msg_errore);
}


